# TODO

A list of things to do.

## For Jabed

- [ ] Update README.md
- [ ] Write docs
- [ ] provide examples
- [ ] compute physical observables

## For Aritra

- [x] Write K-space
- [x] fix code for all lattice types
- [x] n orbital
- [ ] support for kth nearest neighbour (1st nearest already there)

## Ambitious goals

- [ ] write NEGF (Non-equilibrium Green's function)
- [ ] allow different types of layers in one moire lattice (don't even know if physically meaningful)
    Note: not meaningful in most cases so `won't fix`
- [ ] allow tri-layers, tetra-layers etc
